@@ -17,8 +17,11 @@ class Database:
       f.close(); return r
   def remove(self, cb):
     with open(self.path, 'r') as r, open(self.path + '.bak', 'w') as w:
+      o = True
       for l in r:
         try:
-          if not cb(json.loads(l)): w.write(l)
+          if not cb(json.loads(l)): o = False
+          else: o = True
         except: None
+        if o: w.write(l)
       r.close(); w.close(); os.remove(self.path); os.rename(self.path + '.bak', self.path)
\ No newline at end of file
